package edu.kit.ipd.descartes.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import edu.kit.ipd.descartes.core.CorePackage;
import edu.kit.ipd.descartes.identifier.IdentifierPackage;
import edu.kit.ipd.descartes.mm.adaptation.Action;
import edu.kit.ipd.descartes.mm.adaptation.ActionReference;
import edu.kit.ipd.descartes.mm.adaptation.AdaptationActionOperation;
import edu.kit.ipd.descartes.mm.adaptation.AdaptationPackage;
import edu.kit.ipd.descartes.mm.adaptation.AdaptationPlan;
import edu.kit.ipd.descartes.mm.adaptation.AdaptationProcess;
import edu.kit.ipd.descartes.mm.adaptation.BranchAction;
import edu.kit.ipd.descartes.mm.adaptation.Event;
import edu.kit.ipd.descartes.mm.adaptation.ImportDeclaration;
import edu.kit.ipd.descartes.mm.adaptation.LoopAction;
import edu.kit.ipd.descartes.mm.adaptation.Objective;
import edu.kit.ipd.descartes.mm.adaptation.OverallGoal;
import edu.kit.ipd.descartes.mm.adaptation.Parameter;
import edu.kit.ipd.descartes.mm.adaptation.Specification;
import edu.kit.ipd.descartes.mm.adaptation.StartAction;
import edu.kit.ipd.descartes.mm.adaptation.StopAction;
import edu.kit.ipd.descartes.mm.adaptation.Strategy;
import edu.kit.ipd.descartes.mm.adaptation.Tactic;
import edu.kit.ipd.descartes.mm.adaptation.WeightedMetric;
import edu.kit.ipd.descartes.mm.adaptation.WeightedTactic;
import edu.kit.ipd.descartes.mm.adaptation.WeightingFunction;
import edu.kit.ipd.descartes.mm.adaptationpoints.AdaptationpointsPackage;
import edu.kit.ipd.descartes.mm.adaptationpoints.ModelEntityConfigurationRange;
import edu.kit.ipd.descartes.mm.adaptationpoints.ModelVariableConfigurationRange;
import edu.kit.ipd.descartes.mm.adaptationpoints.OclConstraint;
import edu.kit.ipd.descartes.mm.adaptationpoints.PropertyRange;
import edu.kit.ipd.descartes.mm.adaptationpoints.SetOfConfigurations;
import edu.kit.ipd.descartes.perfdatarepo.Impact;
import edu.kit.ipd.descartes.perfdatarepo.MeasuredEntity;
import edu.kit.ipd.descartes.perfdatarepo.MetricType;
import edu.kit.ipd.descartes.perfdatarepo.MetricValue;
import edu.kit.ipd.descartes.perfdatarepo.PerfdatarepoPackage;
import edu.kit.ipd.descartes.perfdatarepo.Result;
import edu.kit.ipd.descartes.services.StaLangGrammarAccess;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;

@SuppressWarnings("all")
public abstract class AbstractStaLangSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private StaLangGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == AdaptationPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case AdaptationPackage.ACTION:
				if(context == grammarAccess.getActionRule()) {
					sequence_Action(context, (Action) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.ACTION_REFERENCE:
				if(context == grammarAccess.getAbstractControlFlowElementRule() ||
				   context == grammarAccess.getActionReferenceRule()) {
					sequence_ActionReference(context, (ActionReference) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.ADAPTATION_ACTION_OPERATION:
				if(context == grammarAccess.getAdaptationActionOperationRule()) {
					sequence_AdaptationActionOperation(context, (AdaptationActionOperation) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.ADAPTATION_PLAN:
				if(context == grammarAccess.getAdaptationPlanRule()) {
					sequence_AdaptationPlan(context, (AdaptationPlan) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.ADAPTATION_PROCESS:
				if(context == grammarAccess.getAdaptationProcessRule()) {
					sequence_AdaptationProcess(context, (AdaptationProcess) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.BRANCH_ACTION:
				if(context == grammarAccess.getAbstractControlFlowElementRule() ||
				   context == grammarAccess.getBranchActionRule()) {
					sequence_BranchAction(context, (BranchAction) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.EVENT:
				if(context == grammarAccess.getEventRule()) {
					sequence_Event(context, (Event) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.IMPORT_DECLARATION:
				if(context == grammarAccess.getImportDeclarationRule()) {
					sequence_ImportDeclaration(context, (ImportDeclaration) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.LOOP_ACTION:
				if(context == grammarAccess.getAbstractControlFlowElementRule() ||
				   context == grammarAccess.getLoopActionRule()) {
					sequence_LoopAction(context, (LoopAction) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.OBJECTIVE:
				if(context == grammarAccess.getObjectiveRule()) {
					sequence_Objective(context, (Objective) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.OVERALL_GOAL:
				if(context == grammarAccess.getOverallGoalRule()) {
					sequence_OverallGoal(context, (OverallGoal) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.PARAMETER:
				if(context == grammarAccess.getParameterRule()) {
					sequence_Parameter(context, (Parameter) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.SPECIFICATION:
				if(context == grammarAccess.getSpecificationRule()) {
					sequence_Specification(context, (Specification) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.START_ACTION:
				if(context == grammarAccess.getAbstractControlFlowElementRule() ||
				   context == grammarAccess.getStartActionRule()) {
					sequence_StartAction(context, (StartAction) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.STOP_ACTION:
				if(context == grammarAccess.getAbstractControlFlowElementRule() ||
				   context == grammarAccess.getStopActionRule()) {
					sequence_StopAction(context, (StopAction) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.STRATEGY:
				if(context == grammarAccess.getStrategyRule()) {
					sequence_Strategy(context, (Strategy) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.TACTIC:
				if(context == grammarAccess.getTacticRule()) {
					sequence_Tactic(context, (Tactic) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.WEIGHTED_METRIC:
				if(context == grammarAccess.getWeightedMetricRule()) {
					sequence_WeightedMetric(context, (WeightedMetric) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.WEIGHTED_TACTIC:
				if(context == grammarAccess.getWeightedTacticRule()) {
					sequence_WeightedTactic(context, (WeightedTactic) semanticObject); 
					return; 
				}
				else break;
			case AdaptationPackage.WEIGHTING_FUNCTION:
				if(context == grammarAccess.getWeightingFunctionRule()) {
					sequence_WeightingFunction(context, (WeightingFunction) semanticObject); 
					return; 
				}
				else break;
			}
		else if(semanticObject.eClass().getEPackage() == AdaptationpointsPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case AdaptationpointsPackage.MODEL_ENTITY_CONFIGURATION_RANGE:
				if(context == grammarAccess.getAdaptationPointRule() ||
				   context == grammarAccess.getModelEntityConfigurationRangeRule()) {
					sequence_ModelEntityConfigurationRange(context, (ModelEntityConfigurationRange) semanticObject); 
					return; 
				}
				else break;
			case AdaptationpointsPackage.MODEL_VARIABLE_CONFIGURATION_RANGE:
				if(context == grammarAccess.getAdaptationPointRule() ||
				   context == grammarAccess.getModelVariableConfigurationRangeRule()) {
					sequence_ModelVariableConfigurationRange(context, (ModelVariableConfigurationRange) semanticObject); 
					return; 
				}
				else break;
			case AdaptationpointsPackage.OCL_CONSTRAINT:
				if(context == grammarAccess.getOclConstraintRule()) {
					sequence_OclConstraint(context, (OclConstraint) semanticObject); 
					return; 
				}
				else break;
			case AdaptationpointsPackage.PROPERTY_RANGE:
				if(context == grammarAccess.getPropertyRangeRule() ||
				   context == grammarAccess.getVariationTypeRule()) {
					sequence_PropertyRange(context, (PropertyRange) semanticObject); 
					return; 
				}
				else break;
			case AdaptationpointsPackage.SET_OF_CONFIGURATIONS:
				if(context == grammarAccess.getSetOfConfigurationsRule() ||
				   context == grammarAccess.getVariationTypeRule()) {
					sequence_SetOfConfigurations(context, (SetOfConfigurations) semanticObject); 
					return; 
				}
				else break;
			}
		else if(semanticObject.eClass().getEPackage() == PerfdatarepoPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case PerfdatarepoPackage.IMPACT:
				if(context == grammarAccess.getImpactRule()) {
					sequence_Impact(context, (Impact) semanticObject); 
					return; 
				}
				else break;
			case PerfdatarepoPackage.MEASURED_ENTITY:
				if(context == grammarAccess.getMeasuredEntityRule()) {
					sequence_MeasuredEntity(context, (MeasuredEntity) semanticObject); 
					return; 
				}
				else break;
			case PerfdatarepoPackage.METRIC_TYPE:
				if(context == grammarAccess.getMetricTypeRule()) {
					sequence_MetricType(context, (MetricType) semanticObject); 
					return; 
				}
				else break;
			case PerfdatarepoPackage.METRIC_VALUE:
				if(context == grammarAccess.getMetricValueRule()) {
					sequence_MetricValue(context, (MetricValue) semanticObject); 
					return; 
				}
				else break;
			case PerfdatarepoPackage.RESULT:
				if(context == grammarAccess.getResultRule()) {
					sequence_Result(context, (Result) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     (id=EString predecessor=[AbstractControlFlowElement|EString]? successor=[AbstractControlFlowElement|EString]? refersTo=[Action|EString])
	 */
	protected void sequence_ActionReference(EObject context, ActionReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         name=EString 
	 *         outputParam=[Parameter|EString]? 
	 *         (inputParams+=[Parameter|EString] inputParams+=[Parameter|EString]*)? 
	 *         referredAdaptationPoint=[AdaptationPoint|EString] 
	 *         adaptationActionOperation=AdaptationActionOperation
	 *     )
	 */
	protected void sequence_Action(EObject context, Action semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (adaptationOperationScope=AdaptationScope adaptationOperationDirection=AdaptationDirection)
	 */
	protected void sequence_AdaptationActionOperation(EObject context, AdaptationActionOperation semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.ADAPTATION_ACTION_OPERATION__ADAPTATION_OPERATION_SCOPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.ADAPTATION_ACTION_OPERATION__ADAPTATION_OPERATION_SCOPE));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.ADAPTATION_ACTION_OPERATION__ADAPTATION_OPERATION_DIRECTION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.ADAPTATION_ACTION_OPERATION__ADAPTATION_OPERATION_DIRECTION));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getAdaptationActionOperationAccess().getAdaptationOperationScopeAdaptationScopeParserRuleCall_3_0(), semanticObject.getAdaptationOperationScope());
		feeder.accept(grammarAccess.getAdaptationActionOperationAccess().getAdaptationOperationDirectionAdaptationDirectionParserRuleCall_5_0(), semanticObject.getAdaptationOperationDirection());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString (steps+=AbstractControlFlowElement steps+=AbstractControlFlowElement*)?)
	 */
	protected void sequence_AdaptationPlan(EObject context, AdaptationPlan semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         name=EString 
	 *         tactics+=Tactic 
	 *         tactics+=Tactic* 
	 *         actions+=Action 
	 *         actions+=Action* 
	 *         strategies+=Strategy 
	 *         strategies+=Strategy* 
	 *         (parameters+=Parameter parameters+=Parameter*)? 
	 *         goal=OverallGoal 
	 *         importDeclaration=ImportDeclaration?
	 *     )
	 */
	protected void sequence_AdaptationProcess(EObject context, AdaptationProcess semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         condition=EString? 
	 *         predecessor=[AbstractControlFlowElement|EString]? 
	 *         successor=[AbstractControlFlowElement|EString]? 
	 *         context=[Entity|EString]? 
	 *         conditionTrueBranch=AdaptationPlan 
	 *         conditionFalseBranch=AdaptationPlan
	 *     )
	 */
	protected void sequence_BranchAction(EObject context, BranchAction semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString)
	 */
	protected void sequence_Event(EObject context, Event semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString before=[Result|EString] after=[Result|EString])
	 */
	protected void sequence_Impact(EObject context, Impact semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
			if(transientValues.isValueTransient(semanticObject, PerfdatarepoPackage.Literals.IMPACT__BEFORE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, PerfdatarepoPackage.Literals.IMPACT__BEFORE));
			if(transientValues.isValueTransient(semanticObject, PerfdatarepoPackage.Literals.IMPACT__AFTER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, PerfdatarepoPackage.Literals.IMPACT__AFTER));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getImpactAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getImpactAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getImpactAccess().getBeforeResultEStringParserRuleCall_6_0_1(), semanticObject.getBefore());
		feeder.accept(grammarAccess.getImpactAccess().getAfterResultEStringParserRuleCall_8_0_1(), semanticObject.getAfter());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     importURI=EString
	 */
	protected void sequence_ImportDeclaration(EObject context, ImportDeclaration semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.IMPORT_DECLARATION__IMPORT_URI) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.IMPORT_DECLARATION__IMPORT_URI));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getImportDeclarationAccess().getImportURIEStringParserRuleCall_1_0(), semanticObject.getImportURI());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         predecessor=[AbstractControlFlowElement|EString]? 
	 *         successor=[AbstractControlFlowElement|EString]? 
	 *         counter=[Parameter|EString] 
	 *         body=AdaptationPlan
	 *     )
	 */
	protected void sequence_LoopAction(EObject context, LoopAction semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString metricTypes+=[MetricType|EString] metricTypes+=[MetricType|EString]*)
	 */
	protected void sequence_MeasuredEntity(EObject context, MeasuredEntity semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString)
	 */
	protected void sequence_MetricType(EObject context, MetricType semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getMetricTypeAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getMetricTypeAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString value=EDouble measuredEntity=[MeasuredEntity|EString] metricType=[MetricType|EString])
	 */
	protected void sequence_MetricValue(EObject context, MetricValue semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
			if(transientValues.isValueTransient(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__MEASURED_ENTITY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__MEASURED_ENTITY));
			if(transientValues.isValueTransient(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__METRIC_TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__METRIC_TYPE));
			if(transientValues.isValueTransient(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, PerfdatarepoPackage.Literals.METRIC_VALUE__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getMetricValueAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getMetricValueAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getMetricValueAccess().getValueEDoubleParserRuleCall_6_0(), semanticObject.getValue());
		feeder.accept(grammarAccess.getMetricValueAccess().getMeasuredEntityMeasuredEntityEStringParserRuleCall_8_0_1(), semanticObject.getMeasuredEntity());
		feeder.accept(grammarAccess.getMetricValueAccess().getMetricTypeMetricTypeEStringParserRuleCall_10_0_1(), semanticObject.getMetricType());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString adaptableEntity=[Entity|EString] variationPossibility=VariationType)
	 */
	protected void sequence_ModelEntityConfigurationRange(EObject context, ModelEntityConfigurationRange semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.MODEL_ENTITY_CONFIGURATION_RANGE__VARIATION_POSSIBILITY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.MODEL_ENTITY_CONFIGURATION_RANGE__VARIATION_POSSIBILITY));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.MODEL_ENTITY_CONFIGURATION_RANGE__ADAPTABLE_ENTITY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.MODEL_ENTITY_CONFIGURATION_RANGE__ADAPTABLE_ENTITY));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelEntityConfigurationRangeAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getModelEntityConfigurationRangeAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getModelEntityConfigurationRangeAccess().getAdaptableEntityEntityEStringParserRuleCall_6_0_1(), semanticObject.getAdaptableEntity());
		feeder.accept(grammarAccess.getModelEntityConfigurationRangeAccess().getVariationPossibilityVariationTypeParserRuleCall_8_0(), semanticObject.getVariationPossibility());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString minValue=EDouble maxValue=EDouble adaptableEntity=[AdaptableEntity|EString])
	 */
	protected void sequence_ModelVariableConfigurationRange(EObject context, ModelVariableConfigurationRange semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__ADAPTABLE_ENTITY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__ADAPTABLE_ENTITY));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__MIN_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__MIN_VALUE));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__MAX_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.MODEL_VARIABLE_CONFIGURATION_RANGE__MAX_VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelVariableConfigurationRangeAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getModelVariableConfigurationRangeAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getModelVariableConfigurationRangeAccess().getMinValueEDoubleParserRuleCall_6_0(), semanticObject.getMinValue());
		feeder.accept(grammarAccess.getModelVariableConfigurationRangeAccess().getMaxValueEDoubleParserRuleCall_8_0(), semanticObject.getMaxValue());
		feeder.accept(grammarAccess.getModelVariableConfigurationRangeAccess().getAdaptableEntityAdaptableEntityEStringParserRuleCall_10_0_1(), semanticObject.getAdaptableEntity());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString specifications+=Specification specifications+=Specification*)
	 */
	protected void sequence_Objective(EObject context, Objective semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=EString oclString=EString)
	 */
	protected void sequence_OclConstraint(EObject context, OclConstraint semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.OCL_CONSTRAINT__OCL_STRING) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.OCL_CONSTRAINT__OCL_STRING));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.OCL_CONSTRAINT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.OCL_CONSTRAINT__NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getOclConstraintAccess().getNameEStringParserRuleCall_1_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getOclConstraintAccess().getOclStringEStringParserRuleCall_4_0(), semanticObject.getOclString());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (description=EString objectives+=Objective objectives+=Objective*)
	 */
	protected void sequence_OverallGoal(EObject context, OverallGoal semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=EString type=EString value=EString)
	 */
	protected void sequence_Parameter(EObject context, Parameter semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.PARAMETER__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.PARAMETER__NAME));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.PARAMETER__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.PARAMETER__TYPE));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.PARAMETER__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.PARAMETER__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getParameterAccess().getNameEStringParserRuleCall_1_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getParameterAccess().getTypeEStringParserRuleCall_4_0(), semanticObject.getType());
		feeder.accept(grammarAccess.getParameterAccess().getValueEStringParserRuleCall_6_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (minValueConstraint=OclConstraint maxValueConstraint=OclConstraint)
	 */
	protected void sequence_PropertyRange(EObject context, PropertyRange semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.PROPERTY_RANGE__MIN_VALUE_CONSTRAINT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.PROPERTY_RANGE__MIN_VALUE_CONSTRAINT));
			if(transientValues.isValueTransient(semanticObject, AdaptationpointsPackage.Literals.PROPERTY_RANGE__MAX_VALUE_CONSTRAINT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationpointsPackage.Literals.PROPERTY_RANGE__MAX_VALUE_CONSTRAINT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getPropertyRangeAccess().getMinValueConstraintOclConstraintParserRuleCall_3_0(), semanticObject.getMinValueConstraint());
		feeder.accept(grammarAccess.getPropertyRangeAccess().getMaxValueConstraintOclConstraintParserRuleCall_5_0(), semanticObject.getMaxValueConstraint());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString timestamp=EDate metricValues+=MetricValue metricValues+=MetricValue*)
	 */
	protected void sequence_Result(EObject context, Result semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     ((variants+=[Entity|EString] variants+=[Entity|EString]*)? valueConstraint=OclConstraint)
	 */
	protected void sequence_SetOfConfigurations(EObject context, SetOfConfigurations semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (value=EDouble relationalOperator=RelationalOperator metricType=[MetricType|EString])
	 */
	protected void sequence_Specification(EObject context, Specification semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.SPECIFICATION__METRIC_TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.SPECIFICATION__METRIC_TYPE));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.SPECIFICATION__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.SPECIFICATION__VALUE));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.SPECIFICATION__RELATIONAL_OPERATOR) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.SPECIFICATION__RELATIONAL_OPERATOR));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getSpecificationAccess().getValueEDoubleParserRuleCall_3_0(), semanticObject.getValue());
		feeder.accept(grammarAccess.getSpecificationAccess().getRelationalOperatorRelationalOperatorParserRuleCall_5_0(), semanticObject.getRelationalOperator());
		feeder.accept(grammarAccess.getSpecificationAccess().getMetricTypeMetricTypeEStringParserRuleCall_7_0_1(), semanticObject.getMetricType());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString predecessor=[AbstractControlFlowElement|EString]? successor=[AbstractControlFlowElement|EString]?)
	 */
	protected void sequence_StartAction(EObject context, StartAction semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString predecessor=[AbstractControlFlowElement|EString]? successor=[AbstractControlFlowElement|EString]?)
	 */
	protected void sequence_StopAction(EObject context, StopAction semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         name=EString 
	 *         objective=[Objective|EString] 
	 *         triggeringEvents=Event 
	 *         tactics+=WeightedTactic 
	 *         tactics+=WeightedTactic* 
	 *         weightingFunction=WeightingFunction
	 *     )
	 */
	protected void sequence_Strategy(EObject context, Strategy semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         name=EString 
	 *         (inputParams+=[Parameter|EString] inputParams+=[Parameter|EString]*)? 
	 *         outputParam=[Parameter|EString]? 
	 *         implementedPlan=AdaptationPlan
	 *     )
	 */
	protected void sequence_Tactic(EObject context, Tactic semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString weight=EDouble metricType=[MetricType|EString])
	 */
	protected void sequence_WeightedMetric(EObject context, WeightedMetric semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, IdentifierPackage.Literals.IDENTIFIER__ID));
			if(transientValues.isValueTransient(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CorePackage.Literals.NAMED_ELEMENT__NAME));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.WEIGHTED_METRIC__WEIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.WEIGHTED_METRIC__WEIGHT));
			if(transientValues.isValueTransient(semanticObject, AdaptationPackage.Literals.WEIGHTED_METRIC__METRIC_TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AdaptationPackage.Literals.WEIGHTED_METRIC__METRIC_TYPE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getWeightedMetricAccess().getIdEStringParserRuleCall_1_0(), semanticObject.getId());
		feeder.accept(grammarAccess.getWeightedMetricAccess().getNameEStringParserRuleCall_4_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getWeightedMetricAccess().getWeightEDoubleParserRuleCall_6_0(), semanticObject.getWeight());
		feeder.accept(grammarAccess.getWeightedMetricAccess().getMetricTypeMetricTypeEStringParserRuleCall_8_0_1(), semanticObject.getMetricType());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         id=EString 
	 *         name=EString 
	 *         currentWeight=EDouble 
	 *         defaultWeight=EDouble 
	 *         usedTactic=[Tactic|EString] 
	 *         lastImpact=[Impact|EString]?
	 *     )
	 */
	protected void sequence_WeightedTactic(EObject context, WeightedTactic semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (id=EString name=EString weightingFunctionImplementation=EString weightedMetrics+=WeightedMetric weightedMetrics+=WeightedMetric*)
	 */
	protected void sequence_WeightingFunction(EObject context, WeightingFunction semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
}
